@@ -1,5 +1,5 @@
 #![allow(clippy::redundant_static_lifetimes)]
-#![allow(clippy::unreadable_literal)]
 
+#[rustfmt::skip]
 mod unprintable;
 pub(super) use unprintable::UNPRINTABLE;
