@@ -91,16 +91,16 @@ pub trait Quote {
 
 macro_rules! r#impl {
     ( $($type:ty),+ ) => {
-        $(
-            impl Quote for $type {
-                #[inline]
-                fn escape(&self, f: &mut Formatter<'_>) -> $crate::Result {
-                    use super::escape::Escape;
+    $(
+        impl Quote for $type {
+            #[inline]
+            fn escape(&self, f: &mut Formatter<'_>) -> $crate::Result {
+                use super::escape::Escape;
 
-                    Escape::escape(self, &mut f.0).map_err(Error)
-                }
+                Escape::escape(self, &mut f.0).map_err(Error)
             }
-        )+
+        }
+    )+
     };
 }
 r#impl!(char, str, [u8]);
@@ -112,6 +112,13 @@ impl<const N: usize> Quote for [u8; N] {
     }
 }
 
+impl Quote for CStr {
+    #[inline]
+    fn escape(&self, f: &mut Formatter<'_>) -> Result {
+        self.to_bytes().escape(f)
+    }
+}
+
 #[cfg(feature = "alloc")]
 macro_rules! impl_with_deref {
     ( $($type:ty),+ ) => {
@@ -129,13 +136,6 @@ macro_rules! impl_with_deref {
     };
 }
 
-impl Quote for CStr {
-    #[inline]
-    fn escape(&self, f: &mut Formatter<'_>) -> Result {
-        self.to_bytes().escape(f)
-    }
-}
-
 #[cfg(feature = "alloc")]
 mod alloc {
     use alloc::ffi::CString;
@@ -152,6 +152,7 @@ mod std {
         target_os = "hermit",
         target_os = "solid_asp3",
         target_os = "wasi",
+        target_os = "xous",
         unix,
         windows,
     ))]
@@ -182,12 +183,16 @@ mod std {
                         target_env = "sgx",
                     ))]
                     use std::os::fortanix_sgx as os;
+                    #[cfg(target_os = "hermit")]
+                    use std::os::hermit as os;
                     #[cfg(target_os = "solid_asp3")]
                     use std::os::solid as os;
-                    #[cfg(any(target_os = "hermit", unix))]
+                    #[cfg(unix)]
                     use std::os::unix as os;
                     #[cfg(target_os = "wasi")]
                     use std::os::wasi as os;
+                    #[cfg(target_os = "xous")]
+                    use std::os::xous as os;
 
                     use os::ffi::OsStrExt;
 
